@@ -133,10 +133,10 @@ from typing import Any, Callable, List, Pattern, Tuple
 
 # 3rd party
 import importlib_resources
+from consolekit.terminal_colours import Fore
 from docutils import nodes
 from docutils.nodes import Node, system_message
 from docutils.parsers.rst import roles
-from domdf_python_tools.terminal_colours import Fore
 from sphinx.application import Sphinx
 from sphinx.ext.autodoc import UNINITIALIZED_ATTR, ModuleDocumenter
 from sphinx.util.docutils import SphinxRole
@@ -261,7 +261,7 @@ class RegexDocumenter(VariableDocumenter):
 				else:
 					the_pattern = self.object.pattern
 
-				the_pattern = the_pattern.replace("`", r"\`")
+				the_pattern = the_pattern.replace('`', r"\`")
 				self.add_line(f'     **Pattern**, ":regex:`{the_pattern}`"', sourcename)
 
 			if not no_flag:
@@ -382,10 +382,10 @@ class RegexParser:
 
 				if what is AT:
 					if content is AT_BEGINNING:
-						buf.append(type(self).AT_COLOUR("^"))
+						buf.append(type(self).AT_COLOUR('^'))
 						continue
 					elif content is AT_END:
-						buf.append(type(self).AT_COLOUR("$"))
+						buf.append(type(self).AT_COLOUR('$'))
 						continue
 					elif content is AT_BEGINNING_STRING:
 						buf.append(type(self).AT_COLOUR(r"\A"))
@@ -401,11 +401,11 @@ class RegexParser:
 						continue
 
 				if what is SUBPATTERN:
-					buf.append(type(self).SUBPATTERN_COLOUR("("))
+					buf.append(type(self).SUBPATTERN_COLOUR('('))
 					group, add_flags, del_flags, subpattern = content
 					# print(group, add_flags, del_flags)
 					_parse_pattern(subpattern)
-					buf.append(type(self).SUBPATTERN_COLOUR(")"))
+					buf.append(type(self).SUBPATTERN_COLOUR(')'))
 					continue
 
 				if what is LITERAL:
@@ -415,12 +415,12 @@ class RegexParser:
 
 				if what is IN:
 					if len(content) > 1 or content[0][0] is RANGE:
-						buf.append(type(self).IN_COLOUR("["))
+						buf.append(type(self).IN_COLOUR('['))
 
 					_parse_pattern(content)
 
 					if len(content) > 1 or content[0][0] is RANGE:
-						buf.append(type(self).IN_COLOUR("]"))
+						buf.append(type(self).IN_COLOUR(']'))
 					continue
 
 				if what is MAX_REPEAT or what is MIN_REPEAT:
@@ -428,23 +428,23 @@ class RegexParser:
 					_parse_pattern(item)
 
 					if min_ == 0 and max_ is MAXREPEAT:
-						buf.append(type(self).REPEAT_COLOUR("*"))
+						buf.append(type(self).REPEAT_COLOUR('*'))
 					elif min_ == 1 and max_ is MAXREPEAT:
-						buf.append(type(self).REPEAT_COLOUR("+"))
+						buf.append(type(self).REPEAT_COLOUR('+'))
 					elif min_ == 0 and max_ == 1:
-						buf.append(type(self).REPEAT_COLOUR("?"))
+						buf.append(type(self).REPEAT_COLOUR('?'))
 					elif min_ == max_:
-						buf.append(type(self).REPEAT_BRACE_COLOUR("{"))
+						buf.append(type(self).REPEAT_BRACE_COLOUR('{'))
 						buf.append(type(self).REPEAT_COLOUR(str(min_)))
-						buf.append(type(self).REPEAT_BRACE_COLOUR("}"))
+						buf.append(type(self).REPEAT_BRACE_COLOUR('}'))
 					else:
-						buf.append(type(self).REPEAT_BRACE_COLOUR("{"))
+						buf.append(type(self).REPEAT_BRACE_COLOUR('{'))
 						buf.append(type(self).REPEAT_COLOUR(str(min_)))
-						buf.append(type(self).LITERAL_COLOUR(","))
+						buf.append(type(self).LITERAL_COLOUR(','))
 						buf.append(type(self).REPEAT_COLOUR(str(max)))
-						buf.append(type(self).REPEAT_BRACE_COLOUR("}"))
+						buf.append(type(self).REPEAT_BRACE_COLOUR('}'))
 					if what is MIN_REPEAT:
-						buf.append(type(self).REPEAT_COLOUR("?"))
+						buf.append(type(self).REPEAT_COLOUR('?'))
 
 					continue
 				#
@@ -477,18 +477,18 @@ class RegexParser:
 				if what is BRANCH:
 					for branch in content[1]:
 						_parse_pattern(branch)
-						buf.append(type(self).BRANCH_COLOUR("|"))
+						buf.append(type(self).BRANCH_COLOUR('|'))
 					buf.pop(-1)
 					continue
 
 				if what is RANGE:
 					buf.append(type(self).LITERAL_COLOUR(chr(content[0])))
-					buf.append(type(self).AT_COLOUR("-"))
+					buf.append(type(self).AT_COLOUR('-'))
 					buf.append(type(self).LITERAL_COLOUR(chr(content[1])))
 					continue
 
 				if what is ANY:
-					buf.append(type(self).ANY_COLOUR("."))
+					buf.append(type(self).ANY_COLOUR('.'))
 					continue
 
 				print(what, content)
@@ -572,17 +572,17 @@ class TerminalRegexParser(RegexParser):
 
 
 	The formatting is controlled by the following functions,
-	which are instances of :class:`domdf_python_tools.terminal_colours.Colour`:
+	which are instances of :class:`consolekit.terminal_colours.Colour`:
 
-	* ``AT_COLOUR`` -> :attr:`~domdf_python_tools.terminal_colours.Fore.YELLOW` -- Used for e.g. :regex:`^\A\b\B\Z$`
-	* ``SUBPATTERN_COLOUR`` -> :attr:`~domdf_python_tools.terminal_colours.Fore.LIGHTYELLOW_EX` -- Used for the parentheses around subpatterns, e.g. :regex:`(Hello) World`
-	* ``IN_COLOUR`` -> :attr:`~domdf_python_tools.terminal_colours.Fore.LIGHTRED_EX` -- Used for the square brackets around character sets, e.g. :regex:`[Hh]ello`
-	* ``REPEAT_COLOUR`` -> :attr:`~domdf_python_tools.terminal_colours.Fore.LIGHTBLUE_EX` -- Used for repeats, e.g. :regex:`A?B+C*D{2,4}E{5}`
-	* ``REPEAT_BRACE_COLOUR`` -> :attr:`~domdf_python_tools.terminal_colours.Fore.YELLOW` -- Used for the braces around numerical repeats.
-	* ``CATEGORY_COLOUR`` -> :attr:`~domdf_python_tools.terminal_colours.Fore.LIGHTYELLOW_EX` -- Used for categories, e.g. :regex:`\d\D\s\D\w\W`
-	* ``BRANCH_COLOUR`` -> :attr:`~domdf_python_tools.terminal_colours.Fore.YELLOW` -- Used for branches, e.g. :regex:`(Lovely|Horrible) Weather`
-	* ``LITERAL_COLOUR`` -> :attr:`~domdf_python_tools.terminal_colours.Fore.GREEN` -- Used for literal characters.
-	* ``ANY_COLOUR`` -> :attr:`~domdf_python_tools.terminal_colours.Fore.YELLOW` -- Used for the "any" dot ``.``.
+	* ``AT_COLOUR`` -> :attr:`~consolekit.terminal_colours.Fore.YELLOW` -- Used for e.g. :regex:`^\A\b\B\Z$`
+	* ``SUBPATTERN_COLOUR`` -> :attr:`~consolekit.terminal_colours.Fore.LIGHTYELLOW_EX` -- Used for the parentheses around subpatterns, e.g. :regex:`(Hello) World`
+	* ``IN_COLOUR`` -> :attr:`~consolekit.terminal_colours.Fore.LIGHTRED_EX` -- Used for the square brackets around character sets, e.g. :regex:`[Hh]ello`
+	* ``REPEAT_COLOUR`` -> :attr:`~consolekit.terminal_colours.Fore.LIGHTBLUE_EX` -- Used for repeats, e.g. :regex:`A?B+C*D{2,4}E{5}`
+	* ``REPEAT_BRACE_COLOUR`` -> :attr:`~consolekit.terminal_colours.Fore.YELLOW` -- Used for the braces around numerical repeats.
+	* ``CATEGORY_COLOUR`` -> :attr:`~consolekit.terminal_colours.Fore.LIGHTYELLOW_EX` -- Used for categories, e.g. :regex:`\d\D\s\D\w\W`
+	* ``BRANCH_COLOUR`` -> :attr:`~consolekit.terminal_colours.Fore.YELLOW` -- Used for branches, e.g. :regex:`(Lovely|Horrible) Weather`
+	* ``LITERAL_COLOUR`` -> :attr:`~consolekit.terminal_colours.Fore.GREEN` -- Used for literal characters.
+	* ``ANY_COLOUR`` -> :attr:`~consolekit.terminal_colours.Fore.YELLOW` -- Used for the "any" dot ``.``.
 
 	.. versionadded:: 1.2.0
 	"""
@@ -608,7 +608,7 @@ class RegexNode(nodes.literal):
 
 	def __init__(self, rawsource='', text='', *children, **attributes):
 		super().__init__(rawsource, text, *children, **attributes)
-		self.pattern = re.compile(":".join(rawsource.split(":")[2:])[1:-1])
+		self.pattern = re.compile(':'.join(rawsource.split(':')[2:])[1:-1])
 
 
 class Regex(SphinxRole):
