@@ -58,14 +58,26 @@ All shields have the following options:
 
 		The documentation version. Default ``latest``.
 
+	.. rst:directive:option:: target
 
-	**Example**
+		The hyperlink target of the shield. Useful if the documentation uses a custom domain.
+
+		.. versionadded:: 1.8.0
+
+
+	**Examples**
 
 	.. rest-example::
 
 		.. rtfd-shield::
 			:project: sphinx-toolbox
 
+	.. rest-example::
+
+		.. rtfd-shield::
+			:project: attrs
+			:target: https://www.attrs.org/
+
 
 .. rst:directive:: travis-shield
 
@@ -94,6 +106,10 @@ All shields have the following options:
 
 		.. travis-shield::
 
+	.. deprecated:: 1.8.0
+
+		Travis CI is no longer free: https://blog.travis-ci.com/2020-11-02-travis-ci-new-billing
+
 
 .. rst:directive:: actions-shield
 
@@ -383,6 +399,7 @@ from docutils import nodes
 from docutils.nodes import fully_normalize_name, whitespace_normalize_name
 from docutils.parsers.rst import directives, states
 from docutils.parsers.rst.roles import set_classes
+from domdf_python_tools.utils import deprecated
 from sphinx.application import Sphinx
 from sphinx.util.docutils import SphinxDirective
 
@@ -515,12 +532,18 @@ class GitHubBackedShield(Shield):
 class RTFDShield(Shield):
 	"""
 	Shield to show the `ReadTheDocs <https://readthedocs.org/>`_ documentation build status.
+
+	.. versionchanged:: 1.8.0
+
+		Added the ``:target:`` option, to allow a custom target to be specified.
+		Useful if the documentation uses a custom domain.
 	"""
 
 	required_arguments = 0
 	option_spec: OptionSpec = {
 			"project": directives.unchanged_required,
 			"version": str,
+			"target": str,
 			**shield_default_option_spec,
 			}
 
@@ -534,7 +557,9 @@ class RTFDShield(Shield):
 
 		image = SHIELDS_IO / "readthedocs" / project / f"{version}?logo=read-the-docs"
 		self.arguments = [image]
-		self.options["target"] = f"https://{project}.readthedocs.io/en/{version}/"
+
+		if "target" not in self.options:
+			self.options["target"] = f"https://{project}.readthedocs.io/en/{version}/"
 
 		return super().run()
 
@@ -542,6 +567,10 @@ class RTFDShield(Shield):
 class TravisShield(GitHubBackedShield):
 	"""
 	Shield to show the `Travis CI <https://travis-ci.com/>`_ build status.
+
+	.. deprecated:: 1.8.0
+
+		Travis CI is no longer free: https://blog.travis-ci.com/2020-11-02-travis-ci-new-billing
 	"""
 
 	option_spec: OptionSpec = {
@@ -552,6 +581,13 @@ class TravisShield(GitHubBackedShield):
 			**shield_default_option_spec,
 			}
 
+	@deprecated(
+			deprecated_in="1.8.0",
+			removed_in="2.0.0",
+			current_version="1.8.0",
+			details="Travis CI is no longer free.",
+			name=".. travis-shield::"
+			)
 	def run(self) -> List[nodes.Node]:
 		"""
 		Process the content of the shield directive.
