@@ -70,12 +70,14 @@ from docutils.parsers.rst import Directive, roles
 from docutils.transforms import Transform
 from domdf_python_tools.doctools import prettify_docstrings
 from domdf_python_tools.stringlist import StringList
-from pygments.lexer import Lexer  # type: ignore
-from pytest_regressions.file_regression import FileRegressionFixture
+from domdf_python_tools.testing import check_file_regression
+from pygments.lexer import Lexer  # type: ignore  # nodep
+from pytest_regressions.file_regression import FileRegressionFixture  # nodep
 from sphinx.builders import Builder
 from sphinx.config import Config
 from sphinx.domains import Domain, Index
 # from sphinx.environment.collectors import EnvironmentCollector
+from sphinx.domains.python import PythonDomain
 from sphinx.environment.collectors import EnvironmentCollector
 from sphinx.events import EventListener
 from sphinx.events import EventManager as BaseEventManager
@@ -106,7 +108,9 @@ class FakeBuilder(Builder):
 class EventManager(BaseEventManager):
 
 	def connect(self, name: str, callback: Callable, priority: int) -> int:
-		"""Connect a handler to specific event."""
+		"""
+		Connect a handler to specific event.
+		"""
 
 		listener_id = self.next_listener_id
 		self.next_listener_id += 1
@@ -550,8 +554,11 @@ def run_setup(setup_func: _setup_func_type, ) -> RunSetupOutput:  # , buildernam
 
 	:returns: 5-element namedtuple
 	"""
+
 	app = Sphinx()  # buildername
 
+	app.add_domain(PythonDomain)
+
 	try:
 		_additional_nodes = copy.copy(docutils.additional_nodes)
 		docutils.additional_nodes = set()
@@ -622,8 +629,8 @@ def check_html_regression(page: BeautifulSoup, file_regression: FileRegressionFi
 
 	page = remove_html_footer(page)
 	page = remove_html_link_tags(page)
-	file_regression.check(
-			contents=str(StringList(page.prettify())),
+	check_file_regression(
+			StringList(page.prettify()),
+			file_regression,
 			extension=".html",
-			encoding="UTF-8",
 			)
